/*
	ProWesS, PROGS Windowing System
	PROforma, PROGS Font & Raster Manager

	DriverSelect - a routine to select a PROforma driver

	The routine can be passed the name of the menu, or it will default to
	"select driver". You can select whether the screen and/or default driver
	should be included as one of the options.
	The return value is the drivername. This should be a string of length
	PF_MAXDRIVERNAME (or more). It should preferably already be a valid driver
	name on calling. This can then be used to display what the current
	selection is.

	(c) PROGS, Professional & Graphical Software
	written by Joachim Van der Auwera
	started 28 October 1995
*/

#include "PROforma_h"
#include "ProWesS_h"
#include "str_h"

typedef struct {
	PWObject current;
	char *drivername;
	} Global;

static Error exit(PWObject object)
{
	return PWChange(object, PW_SYSTEM_BREAKDOWN, NULL);
}

static Error select(PWObject object, char *item)
{
	Global *g;
	PWQuery(object, PW_GLOBAL_AUXILIARY, &g);
	return STRCopy(item,g->drivername);
}

Error DriverSelect(char *menu_name, char screen, char def, char *drivername)
{
	Error err;
	Gstate gstate;
	PWObject outl=NULL, menu;
	Global g;
	char driver[PF_MAXDRIVERNAME];

	g.drivername=drivername;

	/* set up the outline */

	err=PWCreate(NULL,&outl,PW_TYPE_OUTLINE,
				PW_OUTLINE_TITLE_TEXT, menu_name ? menu_name : "select driver",
				PW_OUTLINE_QUIT,
				PW_OUTLINE_QUIT_KEYPRESS, 27,
				PW_OUTLINE_ACTION_DO, exit,
				PW_WINDOW_YSIZE, short2pt(540),
				PW_GLOBAL_AUXILIARY, &g,
				NULL);
	if (err) goto exit;

	/* set up the item with the current driver */
	/* ..... */

	/* set up the menu with the possible drivers */
	err=PWCreate(outl,&menu,PW_TYPE_MENU,
				PW_MENU_ACTION_SELECT, select,
				PW_MENU_WINDOW_DO, TRUE,
				PW_MENU_UNIQUE,
				NULL);
	if (err) goto exit;

	/* fill the menu */

	err=PWQuery(outl, PW_SYSTEM_GSTATE, &gstate);
	if (err) goto exit;
	PFDriverCount(gstate, NULL);
	if (screen)
	{
		err=PWChange(menu, PW_MENU_ADD, "screen driver", NULL);
		if (err) goto exit;
	}
	if (def)
	{
		err=PWChange(menu, PW_MENU_ADD, "default driver", NULL);
		if (err) goto exit;
	}
	while (!PFDriverNext(gstate, NULL, driver))
	{
		err=PWChange(menu, PW_MENU_ADD_COPY, driver, NULL);
		if (err) goto exit;
	}

	/* activate the window */
	err=PWActivate(outl);

exit:
	if (outl) PWRemove(outl);
	return err;
}
