/*
	ProWesS, PROGS Windowing System
	PROforma, PROGS Font & Raster Manager

	FontSelect - a routine to select a PROforma font

	The routine can be passed the name of the menu, or it will default to
	"select font".
	The return value is the fontname. This should be a string of length
	PF_MAXFONTNAME (or more). It should preferably already be a valid font
	name on calling. This can then be used to display what the current
	selection is.

	(c) PROGS, Professional & Graphical Software
	written by Joachim Van der Auwera
	started 29 October 1995
*/

#include "PROforma_h"
#include "ProWesS_h"
#include "str_h"

typedef struct {
	PWObject current;
	char *fontname;
	} Global;

static Error exit(PWObject object)
{
	return PWChange(object, PW_SYSTEM_BREAKDOWN, NULL);
}

static Error select(PWObject object, char *item)
{
	Global *g;
	PWQuery(object, PW_GLOBAL_AUXILIARY, &g);
	return STRCopy(item,g->fontname);
}

Error FontSelect(char *menu_name, char *fontname)
{
	Error err;
	Gstate gstate;
	PWObject outl=NULL, menu;
	Global g;
	char font[PF_MAXFONTNAME];

	g.fontname=fontname;

	/* set up the outline */

	err=PWCreate(NULL,&outl,PW_TYPE_OUTLINE,
				PW_OUTLINE_TITLE_TEXT, menu_name ? menu_name : "select font",
				PW_OUTLINE_QUIT,
				PW_OUTLINE_QUIT_KEYPRESS, 27,
				PW_OUTLINE_ACTION_DO, exit,
				PW_WINDOW_SIZE, short2pt(720), short2pt(540),
				PW_GLOBAL_AUXILIARY, &g,
				NULL);
	if (err) goto exit;

	/* set up the item with the current driver */
	/* ..... */

	/* set up the menu with the possible drivers */
	err=PWCreate(outl,&menu,PW_TYPE_MENU,
				PW_MENU_ACTION_SELECT, select,
				PW_MENU_WINDOW_DO, TRUE,
				PW_MENU_UNIQUE,
				NULL);
	if (err) goto exit;

	/* fill the menu */

	err=PWQuery(outl, PW_SYSTEM_GSTATE, &gstate);
	if (err) goto exit;
	PFFontCountAll(gstate, NULL);
	while (!PFFontNextName(gstate, font))
	{
		err=PWChange(menu, PW_MENU_ADD_COPY, font, NULL);
		if (err) goto exit;
	}

	/* activate the window */
	err=PWActivate(outl);

exit:
	if (outl) PWRemove(outl);
	return err;
}
